WithinFilter

Struct WithinFilter 

pub struct WithinFilter { /* private fields */ }
Filter that finds geometries contained within a given geometry.

A stored geometry matches if it is completely contained within the search geometry.

Implementations

Source

impl WithinFilter

pub fn new(field: impl Into<String>, geometry: Geometry) -> Self

Creates a new within filter.