pub struct WithinFilter { /* private fields */ }Expand description
Filter that finds geometries contained within a given geometry.
A stored geometry matches if it is completely contained within the search geometry.
Implementations